==> packageinstaller-pkglist_0.3.29.tar.xz: packageinstaller-pkglist/Aragonese.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Aragonese
</name>

<description>
   <am>Aragonese dictionary for hunspell</am>
   <ar>Aragonese dictionary for hunspell</ar>
   <be>Aragonese dictionary for hunspell</be>
   <bg>Aragonese dictionary for hunspell</bg>
   <bn>Aragonese dictionary for hunspell</bn>
   <ca>Aragonese dictionary for hunspell</ca>
   <cs>Aragonese dictionary for hunspell</cs>
   <da>Aragonese dictionary for hunspell</da>
   <de>Aragonese dictionary for hunspell</de>
   <el>λεξικό αραγονικά για hunspell</el>
   <en>Aragonese dictionary for hunspell</en>
   <es_ES>Aragonese dictionary for hunspell</es_ES>
   <es>Diccionario Aragonés para hunspell</es>
   <et>Aragonese dictionary for hunspell</et>
   <eu>Aragonese dictionary for hunspell</eu>
   <fa>Aragonese dictionary for hunspell</fa>
   <fil_PH>Aragonese dictionary for hunspell</fil_PH>
   <fi>Aragonese dictionary for hunspell</fi>
   <fr_BE>Aragonese dictionary for hunspell</fr_BE>
   <fr>Aragonese dictionary for hunspell</fr>
   <gl_ES>Aragonese dictionary for hunspell</gl_ES>
   <he_IL>Aragonese dictionary for hunspell</he_IL>
   <hi>Aragonese dictionary for hunspell</hi>
   <hr>Aragonese dictionary for hunspell</hr>
   <hu>Aragonese dictionary for hunspell</hu>
   <id>Aragonese dictionary for hunspell</id>
   <is>Aragonese dictionary for hunspell</is>
   <it>Aragonese dictionary for hunspell</it>
   <ja>Hunspell 用アラゴン語辞書</ja>
   <kk>Aragonese dictionary for hunspell</kk>
   <ko>Aragonese dictionary for hunspell</ko>
   <lt>Aragonese dictionary for hunspell</lt>
   <mk>Aragonese dictionary for hunspell</mk>
   <mr>Aragonese dictionary for hunspell</mr>
   <nb_NO>Aragonese dictionary for hunspell</nb_NO>
   <nb>Aragonese dictionary for hunspell</nb>
   <nl_BE>Aragonese dictionary for hunspell</nl_BE>
   <nl>Aragonese dictionary for hunspell</nl>
   <pl>Aragonese dictionary for hunspell</pl>
   <pt_BR>Aragonese dictionary for hunspell</pt_BR>
   <pt>Aragonese dictionary for hunspell</pt>
   <ro>Aragonese dictionary for hunspell</ro>
   <ru>Aragonese dictionary for hunspell</ru>
   <sk>Aragonese dictionary for hunspell</sk>
   <sl>Aragonese dictionary for hunspell</sl>
   <sq>Aragonese dictionary for hunspell</sq>
   <sr>Aragonese dictionary for hunspell</sr>
   <sv>Aragonese dictionary for hunspell</sv>
   <th>Aragonese dictionary for hunspell</th>
   <tr>Aragonese dictionary for hunspell</tr>
   <uk>Aragonese dictionary for hunspell</uk>
   <vi>Aragonese dictionary for hunspell</vi>
   <zh_CN>Aragonese dictionary for hunspell</zh_CN>
   <zh_HK>Aragonese dictionary for hunspell</zh_HK>
   <zh_TW>Aragonese dictionary for hunspell</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
hunspell-an
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
hunspell-an
</uninstall_package_names>

</app>

==> packageinstaller-pkglist_0.3.32.tar.xz: packageinstaller-pkglist/Aragonese.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Aragonese
</name>

<description>
   <am>Aragonese dictionary for hunspell</am>
   <ar>Aragonese dictionary for hunspell</ar>
   <be>Aragonese dictionary for hunspell</be>
   <bg>Aragonese dictionary for hunspell</bg>
   <bn>Aragonese dictionary for hunspell</bn>
   <ca>Aragonese dictionary for hunspell</ca>
   <cs>Aragonese dictionary for hunspell</cs>
   <da>Aragonese dictionary for hunspell</da>
   <de>Aragonesisches Wörterbuch für “Hunspell”</de>
   <el>λεξικό αραγονικά για hunspell</el>
   <en>Aragonese dictionary for hunspell</en>
   <es_ES>Diccionario aragonés para hunspell</es_ES>
   <es>Diccionario Aragonés para hunspell</es>
   <et>Aragonese dictionary for hunspell</et>
   <eu>Aragonese dictionary for hunspell</eu>
   <fa>Aragonese dictionary for hunspell</fa>
   <fil_PH>Aragonese dictionary for hunspell</fil_PH>
   <fi>Aragonese dictionary for hunspell</fi>
   <fr_BE>Aragonese dictionary for hunspell</fr_BE>
   <fr>Aragonais dictionnaire pour hunspell</fr>
   <gl_ES>Aragonese dictionary for hunspell</gl_ES>
   <gu>Aragonese dictionary for hunspell</gu>
   <he_IL>Aragonese dictionary for hunspell</he_IL>
   <hi>Aragonese dictionary for hunspell</hi>
   <hr>Aragonese dictionary for hunspell</hr>
   <hu>Aragonese dictionary for hunspell</hu>
   <id>Aragonese dictionary for hunspell</id>
   <is>Aragonese dictionary for hunspell</is>
   <it>Dizionario aragonese per hunspell</it>
   <ja>Hunspell 用アラゴン語辞書</ja>
   <kk>Aragonese dictionary for hunspell</kk>
   <ko>Aragonese dictionary for hunspell</ko>
   <lt>Aragonese dictionary for hunspell</lt>
   <mk>Aragonese dictionary for hunspell</mk>
   <mr>Aragonese dictionary for hunspell</mr>
   <nb_NO>Aragonese dictionary for hunspell</nb_NO>
   <nb>Aragonesisk ordliste for hunspell</nb>
   <nl_BE>Aragonese dictionary for hunspell</nl_BE>
   <nl>Aragonese dictionary for hunspell</nl>
   <pl>Aragonese dictionary for hunspell</pl>
   <pt_BR>Dicionário Aragonês para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
   <pt>Dicionário Aragonês para hunspell</pt>
   <ro>Aragonese dictionary for hunspell</ro>
   <ru>Aragonese dictionary for hunspell</ru>
   <sk>Aragonese dictionary for hunspell</sk>
   <sl>Aragonski slovar za hunspell</sl>
   <sq>Aragonese dictionary for hunspell</sq>
   <sr>Aragonese dictionary for hunspell</sr>
   <sv>Aragonsk ordbok för hunspell</sv>
   <th>Aragonese dictionary for hunspell</th>
   <tr>Hunspell için Aragonca sözlük</tr>
   <uk>Aragonese dictionary for hunspell</uk>
   <vi>Aragonese dictionary for hunspell</vi>
   <zh_CN>Aragonese dictionary for hunspell</zh_CN>
   <zh_HK>Aragonese dictionary for hunspell</zh_HK>
   <zh_TW>Aragonese dictionary for hunspell</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
hunspell-an
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
hunspell-an
</uninstall_package_names>

</app>
